@@ -26,13 +26,15 @@ validate_article <- function(xml_file) {
   if (identical(xml2::xml_name(xml_file), "book")) {
     original_call <- as.character(sys.call(-1)[[1]])
     if (any(original_call %in% c("jst_get_references", "jst_get_footnotes"))) {
-      stop("You are using `", original_call, "` on a book. ",
-           "Neither footnotes nor references are available for books.",
-           call. = FALSE)
+      abort(paste0(
+        "You are using `", original_call, "` on a book. ",
+        "Neither footnotes nor references are available for books."),
+        type = "article_function_for_book")
     } else {
-      stop("You are using `", original_call, "` on a book. ",
-           "Please use `jst_get_book` or `jst_get_chapters` instead.",
-           call. = FALSE)
+      abort(paste0(
+        "You are using `", original_call, "` on a book. ",
+        "Please use `jst_get_book` or `jst_get_chapters` instead."),
+        type = "article_function_for_book")
     }
   } else if (!identical(xml2::xml_name(xml_file), "article")) {
     abort("Unknown input file.")
@@ -41,10 +43,11 @@ validate_article <- function(xml_file) {
 
 validate_book <- function(xml_file) {
   if (identical(xml2::xml_name(xml_file), "article")) {
-    stop(paste0("You are using `", sys.call(-1)[[1]], "` on an article. ",
-                "Please use `jst_get_article`, `jst_get_authors`, `jst_get_references` ",
-                "or `jst_get_footnotes` instead."),
-         call. = FALSE)
+    abort(
+      paste0("You are using `", sys.call(-1)[[1]], "` on an article. ",
+             "Please use `jst_get_article`, `jst_get_authors`, `jst_get_references` ",
+             "or `jst_get_footnotes` instead."),
+      type = "book_function_for_article")
   } else if (!identical(xml2::xml_name(xml_file), "book")) {
     abort("Unknown input file.")
   }
